/*------------------------------------------------------------------------
    File        : HindranceTypeValidator.cls
    Author(s)   : marc
    Created     : 07-03-2018 13:30:13
    Notes       : Customized Validator Class for HindranceType.cls
  ----------------------------------------------------------------------*/

USING Progress.Lang.*.
USING WebApp.System.Manager.*.
USING WebApp.System.Util.*.
USING WebApp.System.Session.*.
USING WebApp.TP.Util.*.

BLOCK-LEVEL ON ERROR UNDO, THROW.

CLASS WebApp.TP.BL.HindranceTypeValidator
      INHERITS   WebApp.System.BusinessLogic.Validator
      IMPLEMENTS WebApp.System.BusinessLogic.Interface.IValidator:

  {"WebApp/TP/BL/HindranceType.i"}

  /*------------------------------------------------------------------------------
   Purpose: Validations for HindranceType
   Notes:  @param dsHindranceType ProDataset to validate
           @param plErrors Validation returns errors
  ------------------------------------------------------------------------------*/
  METHOD PUBLIC VOID Validate( INPUT DATASET dsHindranceType , OUTPUT plErrors AS LOGICAL):

    DEFINE VARIABLE lNewRow AS LOGICAL NO-UNDO.

    FOR EACH ttHindranceType:

      FIND bttHindranceType WHERE ROWID(bttHindranceType) = BUFFER ttHindranceType:BEFORE-ROWID.

      lNewRow = (BUFFER ttHindranceType:ROW-STATE = ROW-CREATED).

      /* Check Mandatory Fields */
      SUPER:MandatoryValidate(INPUT lNewRow, BUFFER ttHindranceType:HANDLE).

      /* Check business rules for HindranceType  */
      THIS-OBJECT:ApplyBusinessRules(BUFFER ttHindranceType:HANDLE, BUFFER bttHindranceType:HANDLE).

      /* Check Record already exits in database */
      THIS-OBJECT:RecordAvailable(lNewRow, "aa-tp_hindrance_type", BUFFER ttHindranceType:HANDLE).

      XrefHelper:spXrefDBValidate( INPUT "aa-tp_hindrance_type",
                                   INPUT BUFFER ttHindranceType:HANDLE,
                                   INPUT BUFFER bttHindranceType:HANDLE).


      IF ResponseManager:hasAnyResponseMessages()
      THEN ASSIGN DATASET    dsHindranceType :ERROR        = TRUE
                  TEMP-TABLE ttHindranceType :ERROR        = TRUE
                  BUFFER     ttHindranceType :ERROR        = TRUE
                  BUFFER     bttHindranceType:ERROR-STRING = ResponseManager:getResponseMessageString().

      ResponseManager:removeAllReponseMessages().

    END.

    plErrors = DATASET dsHindranceType:ERROR.

  END METHOD.

  /*------------------------------------------------------------------------------
   Purpose: Validations for HindranceType
   Notes: @param pcAction check mandatory fields also
          @param plNewRow record is new
          @param pcAfterDataList chr(1) seperated list of current data
          @param pcBeforeDataList chr(1) seperated list of before data
          @param pcErrorMessage Error Message
          @param pcMandatoryFields List of mandatory fields
  ------------------------------------------------------------------------------*/
  METHOD PUBLIC VOID Validate( INPUT  pcAction          AS CHARACTER,
                               INPUT  plNewRow          AS LOGICAL,
                               INPUT  pcAfterDataList   AS CHARACTER,
                               INPUT  pcBeforeDataList  AS CHARACTER,
                               OUTPUT pcErrorMessage    AS CHARACTER,
                               OUTPUT pcMandatoryFields AS CHARACTER):

    DEFINE VARIABLE lErrors    AS LOGICAL        NO-UNDO.

    DEFINE VARIABLE hDataSet   AS HANDLE NO-UNDO.
    ASSIGN hDataSet = DATASET dsHindranceType:HANDLE.

    /* Create record on the basis of chr(1) seperate list of data */
    hDataSet:EMPTY-DATASET.
    SUPER:AddDataRecord(INPUT-OUTPUT DATASET-HANDLE hDataSet,
                        INPUT pcAfterDataList,
                        INPUT pcBeforeDataList).

    /* Select record temp-table */
    FIND ttHindranceType.
    FIND bttHindranceType WHERE ROWID(bttHindranceType) = BUFFER ttHindranceType:BEFORE-ROWID NO-ERROR.

    /* Initialize Mandatory Fields */
    THIS-OBJECT:FieldMandatory("", plNewRow, BUFFER ttHindranceType:HANDLE, OUTPUT DATASET dsFieldMandatory).

    /* Check Mandatory Fields */
    SUPER:MandatoryValidate(plNewRow, BUFFER ttHindranceType:HANDLE).

    /* Check other/custom validations for HindranceType */
    IF pcAction <> 'mandatory-fields'
    THEN DO:

      /* Check business rules for HindranceType  */
      THIS-OBJECT:ApplyBusinessRules(BUFFER ttHindranceType:HANDLE, BUFFER bttHindranceType:HANDLE).

      /* Check Record already exits in database */
      THIS-OBJECT:RecordAvailable(plNewRow, "aa-tp_hindrance_type", BUFFER ttHindranceType:HANDLE).

      XrefHelper:spXrefDBValidate( INPUT "aa-tp_hindrance_type",
                                   INPUT BUFFER ttHindranceType:HANDLE,
                                   INPUT BUFFER bttHindranceType:HANDLE).

    END.

    IF ResponseManager:hasAnyResponseMessages()
    THEN pcErrorMessage = REPLACE(ResponseManager:getResponseMessageString(), "<BR>", "~n").

    ResponseManager:removeAllReponseMessages().
    pcMandatoryFields = THIS-OBJECT:MandatoryFields.

  END METHOD.

   /*------------------------------------------------------------------------------
   Purpose: Validations for HindranceType
   Notes:  @param hDS DATASET-HANDLE to validate
           @param plErrors Validation returns errors
  ------------------------------------------------------------------------------*/
    METHOD PUBLIC VOID Validate ( INPUT DATASET-HANDLE hDS,
                                  OUTPUT plErrors AS LOGICAL):

      DATASET dsHindranceType:COPY-DATASET (hDS).
      THIS-OBJECT:Validate( INPUT DATASET dsHindranceType , OUTPUT plErrors).

    END METHOD.

  /*------------------------------------------------------------------------------
   Purpose: Implementation of mandatory fields;
            sets mandatory fields depending on current data

   Notes:   Syntax:
              setMandatory(fieldname , logical).

              fieldname
                character value corresponds the literal name of field in
                the view model/dataset.

              logical
                logical expression indicaties fields mandatory

            Example:

                setMandatory("date"         , TRUE).
                setMandatory("des"          , TRUE).
                setMandatory("distance"     , (hRowBuffer::ind_external_location)).

             @param pcInvokeField Invloked field
             @param plNewRow indicated new or existing row
             @param hRowBuffer buffer to current data
             @param dsFieldMandatory proDataset to mandatory fields

  ------------------------------------------------------------------------------*/
  METHOD PUBLIC OVERRIDE VOID FieldMandatory( INPUT pcInvokeField AS CHARACTER,
                                              INPUT plNewRow      AS LOGICAL,
                                              INPUT hRowBuffer    AS HANDLE,
                                              OUTPUT DATASET dsFieldMandatory ):


  END METHOD.

  /*------------------------------------------------------------------------------
   Purpose: Implementation of Business Rules
   Notes: @param hAfterBuffer buffer to current data
          @param hBeforeBuffer buffer to before data
     ------------------------------------------------------------------------------*/
  METHOD PUBLIC VOID ApplyBusinessRules( INPUT hAfterBuffer  AS HANDLE,
                                         INPUT hBeforeBuffer AS HANDLE):


  END METHOD.

  /*------------------------------------------------------------------------------
   Purpose: Check new record already exits;
   Notes:   @param plNewRow indicate new record
            @param phRowBuffer record buffer
  ------------------------------------------------------------------------------*/
  METHOD PROTECTED OVERRIDE VOID RecordAvailable( INPUT plNewRow      AS LOGICAL,
                                                  INPUT pcMasterTable AS CHARACTER,
                                                  INPUT phRowBuffer   AS HANDLE):
    /* Skip this line if check is not needed */
    SUPER:RecordAvailable( INPUT plNewRow, INPUT pcMasterTable, INPUT phRowBuffer).

  END METHOD.


END CLASS.
